# LexisMusic.R
# Creates the lexis diagram for the musician data
# August 2011
load('MusicianData.RData')
library(Epi)

xcoh <- data.frame(id = data$Person.num,
                        birth = data$Date.of.birth,
                        entry = data$Date.of.number.one,
                         exit = data$Date.of.death.censored,
                         fail = data$status )
# Convert the character dates into numerical variables (fractional years)
xcoh <- cal.yr( xcoh, wh=2:4 )
# top of the data
head(xcoh)
# Lexis object with timescales of calendar time and age
Lcoh <- Lexis( entry = list( per=entry ),
                exit = list( per=exit, age=exit-birth ),
         exit.status = fail,
                data = xcoh )

# plot Lexis diagram
par(las=1,mai=c(0.8,0.8,0.05,0.05))
plot(Lcoh,xlab='Calendar time',ylab='Age (years)',type='l',pch=19,col='gray',xlim=c(1956.5,2010),yaxt='n')
axis(side=2,at=seq(10,90,10))
deaths=subset(data.frame(Lcoh),fail==1)
rect(xleft=1900,xright=2050,ybottom=27,ytop=28,col='red',border=NA) # add line between 27 and 28
# merge with original data
deaths.plus=merge(deaths,data,by.x='id',by.y='Person.num',all.x=T,all.y=F)
deaths.plus$age.at.fail=deaths.plus$exit-deaths.plus$birth
# add dots at deaths
with(deaths.plus,points(exit,age.at.fail,col='black',pch=19))
