# MusicianMVNA.R
# Analyse the Musician Data using MVNA
# August 2011
load('MusicianData.RData')
library(mvna)
library(splines)

# set up entry and exit times
data$entry=as.numeric(data$Date.of.number.one-data$Date.of.birth)/365.25 #
data$exit[data$status==1]=as.numeric(data$Date.of.death[data$status==1]-data$Date.of.birth[data$status==1])/365.25 #
data$exit[data$status==0]=as.numeric(censor-data$Date.of.birth[data$status==0])/365.25 #

## blow-up the data in years, and Transform to age, period, dead, person years (takes a few minutes)
blow=data
blow$entry=floor(blow$entry) # get yearly ages
blow$exit=floor(blow$exit) # get yearly ages
# blow up the data to one row per year (takes a few minutes)
first=TRUE
for (person in blow$Person.num){
   this.blow=subset(blow,Person.num==person)
   for (age in this.blow$entry:this.blow$exit){
      event=as.numeric(this.blow$status==1)*as.numeric(age==this.blow$exit)
      this.frame=data.frame(id=this.blow$Person.num,start=age,stop=age+1,status=event,years.since=age-this.blow$entry)
      if(first==TRUE){blown.up=this.frame}else{blown.up=rbind(blown.up,this.frame)}
      first=FALSE
   }
}
subset(blown.up,id==345) # have a look at one musician

# Run the model with 7 degrees of freedom
nix.ns<- glm(status~-1+ns(start,df=7),offset=log(stop-start),family=poisson(link='log'),data=blown.up)
# prediction data for plotting
fit.data=data.frame(start=20:91) # ages 20 to 91
fit.data$stop=fit.data$start+100 # set period at risk to 100 musician years
to.plot=predict(nix.ns,fit.data,se.fit=T)
z=qnorm(0.975)
lower=exp(to.plot$fit-(z*to.plot$se.fit))
upper=exp(to.plot$fit+(z*to.plot$se.fit))
mean=exp(to.plot$fit)

# Cumulative hazard using MVNA (gives number of events and number at risk)
# computation of the matrix giving the possible transitions
tra <- matrix(FALSE, nrow = 2, ncol = 2)
tra[1,2] <- TRUE
tra
for.mvna=data
for.mvna$entry=floor(for.mvna$entry) # using years
for.mvna$exit=floor(for.mvna$exit)
for.mvna$id=for.mvna$Person.num
for.mvna$from=0
for.mvna$to[for.mvna$status==1]=1
for.mvna$to[for.mvna$status==0]='cens' # alive are censored
for.mvna=subset(for.mvna,select=c("id", "entry", "exit", "from", "to"))
state.names=as.character(0:1)
mvna <- mvna(for.mvna,state.names=state.names,tra=tra, cens.name='cens')
nrisk=mvna$n.risk
nevent=mvna$n.event['0','1',]
time=mvna$time

### risk and event plot
# colour age 27 red
colour=c('black','red')[as.numeric(time==27)+1]
layout(1:3,widths=1,heights=c(1,1,1.1))
# hazard
par(mai=c(0.2,0.75,0.05,0.05),las=1)
plot(fit.data$start,mean,type='n',lwd=2,xlab='',ylab='',xaxt='n',ylim=c(0,1.4),xlim=c(20,90))
axis(side=1,at=seq(20,90,10),labels=F)
mtext(side=2,las=0,'Death rate per 100 musician-years',padj=-5.8,cex=0.66)
rect(xleft=27,xright=28,ybottom=-1,ytop=100,col='red',border=NA)
lines(fit.data$start,lower,type='l',lwd=1)
lines(fit.data$start,upper,type='l',lwd=1)
lines(fit.data$start,mean,type='l',lwd=2)
# numbers
par(mai=c(0.2,0.75,0.05,0.05),las=1)
plot(time,nevent,type='h',lwd=4,xaxt='n',xlab='',xlim=c(20,90),ylab='Number of deaths',col=colour)
axis(side=1,at=seq(20,90,10),labels=F)
# risk
par(mai=c(0.54,0.75,0.05,0.05),las=1)
plot(time,nrisk,type='h',lwd=4,xaxt='n',xlab='',xlim=c(20,90),ylab='Musicians at risk',col=colour)
mtext(side=1,'Age (years)',padj=3.2,cex=0.85)
axis(side=1,at=seq(20,90,10))
